/**
 * @Classname ConfigListPage
 * @Description TODO
 * @Date 2019/8/22 10:26
 * @Created by Administrator
 */

import React from 'react';
import * as PropTypes from 'prop-types';
import { Button, List, Tag, Pagination } from 'antd';
import { connectAlita } from 'redux-alita';
import AddConfigForm from './widget/AddConfigForm';

class ConfigListPage extends React.Component {

    static propTypes = {
        configPage: PropTypes.object,
    };

    static defaultProps = {
        configPage: { data: {}, isFetching: false },
    };

    constructor(props) {
        super(props);
        this.state = {
            addModalVisible: false,
            currentConfig: undefined,
        };
        this.params = {
            page: 1,
            pageSize: 10,
        };


    }


    // eslint-disable-next-line react/sort-comp
    _queryConfigList(refresh = false) {
        if (refresh) this.params.page = 1;
        let params = { params: this.params };
        this.props.setAlitaState({ funcName: 'configQueryConfigList', params, stateName: 'configPage' })
            .then(resp => {
                console.log('resp=>', resp);
            })
            .catch(e => {
                console.log('queryConfigList err =>', e);
            });
    }


    componentDidMount() {
        this._queryConfigList(true);

    }

    renderListItem(item) {
        return (<List.Item className="list-item" key={item.id}>
            <div style={{ fontSize: 18, color: '#333' }}>{item.key}</div>
            <div style={{ fontSize: 15, color: '#666', marginTop: 5 }}>{item.value}</div>
            <div style={{ fontSize: 15, color: '#666', marginTop: 5 }}>{item.desc}</div>
            <div className="item-footer">
                <Tag color="red">{item.application ? item.application : '通用'}</Tag>
                <Tag color="volcano">{item.profile}</Tag>
                <Tag color="orange">{item.label}</Tag>
                <div style={{ flex: 1 }}/>
                <Button size="small" htmlType="button" icon="edit" onClick={() => {
                    this.setState({ currentConfig: { ...item }, addModalVisible: true });
                }}
                />
                <Button size="small" htmlType="button" icon="delete"/>
            </div>

        </List.Item>);
    }

    render() {

        let { data: configPage, isFetching } = this.props.configPage || {};
        let listPage = { current: 1, pageSize: 15, total: 0 };
        if (configPage) {
            listPage = configPage;
        }


        return (<div className="component-container">
            <div className="headerLine">
                <Button loading={isFetching} htmlType="button"
                        onClick={() => this._queryConfigList(true)}
                        icon="sync"
                />
                <Button htmlType="button"
                        icon="plus"
                        onClick={() => this.setState({ currentConfig: undefined, addModalVisible: true })}
                />
            </div>
            <List dataSource={listPage.records}
                  size="small" bordered
                  renderItem={this.renderListItem.bind(this)}
            />

            <Pagination pageSize={this.params.pageSize} current={listPage.current} total={listPage.total}/>

            <AddConfigForm onCancel={() => this.setState({ addModalVisible: false, currentConfig: undefined })}
                           onRefresh={() => this._queryConfigList(true)}
                           config={this.state.currentConfig}
                           visible={this.state.addModalVisible}
            />

        </div>);

    }


}


export default connectAlita(['configPage'])(ConfigListPage);
